/*
 * Copyright (c) 2011 Tomasz Boleslaw CEDRO <cederom@tlen.pl>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

/** @file Simple framework to bitbang the interface pins.
 */

#include <helper/command.h>
#include <jtag/interface.h>
#include <interface/interface.h>
#include "bitbang.h"

extern struct jtag_interface *jtag_interface;

/*-----------------------------------------------------------------------*/

/*
 * Infrastructure for Tcl interface to bitbang.
 */


COMMAND_HANDLER(handle_bitbang_status)
{
	LOG_DEBUG("%s", __func__);

	if (CMD_ARGC != 0) return ERROR_COMMAND_SYNTAX_ERROR;
	
	oocd_interface_signal_t *sig;
	int signum=0;

	if (!jtag_interface){
		command_print(CMD_CTX, "You need to setup interface first!");
		return ERROR_FAIL;
	}

	if (jtag_interface->bitbang){
		command_print(CMD_CTX, "This interface supports bit-banging.");
	} else {
		command_print(CMD_CTX, "This interface does not support bit-banging.");
	}

	if (jtag_interface->signal==NULL){
		command_print(CMD_CTX, "No signals defined.");
		return 0;
	}

	command_print(CMD_CTX, "Available signals:"); 
	for (sig=jtag_interface->signal;sig;sig=sig->next){
		command_print(CMD_CTX, "%s ", sig->name);
		signum++;
	}

	return signum;
}

COMMAND_HANDLER(handle_bitbang_signal_add)
{
	return ERROR_OK;
}

COMMAND_HANDLER(handle_bitbang_signal_del)
{
	return ERROR_OK;
}

COMMAND_HANDLER(handle_bitbang_work)
{
		if (CMD_ARGC != 0)
		return ERROR_COMMAND_SYNTAX_ERROR;
	return ERROR_OK;
}


static const struct command_registration bitbang_commands[] = {
	{
		.name = "status",
		.handler = handle_bitbang_status,
		.mode = COMMAND_ANY,
		.help = "Show bit-banging status",
	},
	{
		.name = "signal_add",
		.handler = handle_bitbang_signal_add,
		.mode = COMMAND_ANY,
		.help =  "Add interface signal",
          .usage = "[signal_name] [mask] <value>",
	},
	{
		.name = "signal_del",
		.handler = handle_bitbang_signal_del,
		.mode = COMMAND_ANY,
		.help =  "Delete interface signal",
		.usage = "[signal_name]",
	},
	{
		.name = "work",
		.handler = handle_bitbang_work,
		.mode = COMMAND_ANY,
		.help =  "Perform bitbang operations",
		.usage = "[signal_name] to read, [signal_name]=[value] to write",
	},
	COMMAND_REGISTRATION_DONE
};

static const struct command_registration bitbang_commands_group[] = {
	{
		.name = "bitbang",
		.mode = COMMAND_ANY,
		.help = "Interface bit-banging operations",
		.chain = bitbang_commands,
	},
	COMMAND_REGISTRATION_DONE
};


int bitbang_register_commands(struct command_context *ctx)
{
	return register_commands(ctx, NULL, bitbang_commands_group);
}
